@@ -11,7 +11,7 @@
 if [ -f /.backup_run ]; then
    echo "Lockfile from previous backup found!..."
 
-   echo "$(basename "$0"): Lockfile found from previous backup run!" | mail Ssendwait -s "$(cat /etc/hostname) WARNING: make_backup.sh" root@localhost  
+   echo "$(basename "$0"): Lockfile found from previous backup run!" | mail -Ssendwait -s "$(cat /etc/hostname) WARNING: make_backup.sh" root@localhost  
    echo -e '\a' > /dev/console
    sleep 2
    echo -e '\a' > /dev/console
