@@ -10,11 +10,12 @@
 
 source /usr/local/etc/make_backup.conf
 volume_array=($lvm_volumes)
+ret=0
 
-### create snapshots ###
+### delete snapshots ###
 
 for volume in "${volume_array[@]}"; do
-   /usr/sbin/lvremove -y ${lvm_group}/snap-"${volume}" || exit 255
+   /usr/sbin/lvremove -y "${lvm_group}"/snap-"${volume}" || ret=255
 done
 
-exit 0
+exit $ret
